@@ -5,12 +5,15 @@ import argparse
 import atexit
 import json
 import os
+import platform
 import random
 import signal
 import string
 import subprocess
 import sys
 import traceback
+from threading import Thread
+
 import colorama
 from datetime import datetime
 from functools import wraps
@@ -19,11 +22,15 @@ from queue import PriorityQueue
 from typing import Union, Callable, Optional, List, Tuple, Dict, Any, Set, TYPE_CHECKING, cast
 from urllib.parse import unquote
 
+import distro as distro
+from requests import Session
+
 from isisdl.backend.database_helper import DatabaseHelper
+from isisdl.version import __version__
 from isisdl.settings import working_dir_location, is_windows, checksum_algorithm, checksum_base_skip, checksum_num_bytes, \
     testing_download_video_size, testing_download_documents_size, example_config_file_location, config_dir_location, database_file_location, status_time, video_size_discover_num_threads, \
     status_progress_bar_resolution, download_progress_bar_resolution, config_file_location, is_first_time, is_autorun, parse_config_file, lock_file_location, enable_lock, error_file_location, \
-    error_directory_location, systemd_dir_location, master_password
+    error_directory_location, systemd_dir_location, master_password, is_testing
 
 if TYPE_CHECKING:
     from isisdl.backend.request_helper import PreMediaContainer, RequestHelper
@@ -127,7 +134,9 @@ class Config:
         return Config._user[attr]
 
     def to_dict(self) -> Dict[str, Union[bool, str, int, None]]:
-        return {name: getattr(self, name) for name in self.__slots__}
+        ret = {name: getattr(self, name) for name in self.__slots__}
+        ret["username"] = User.sanitize_name(ret["username"])
+        return ret
 
     def start_backup(self) -> None:
         Config._backup = self.to_dict()
@@ -318,7 +327,7 @@ def is_h265(filename: str) -> Optional[bool]:
         return None
 
     if "codec_name" not in video_stream:
-        # Later: Server
+        logger.message("""Assertion failed: "codec_name" not in video_stream""")
         return None
 
     return bool(video_stream["codec_name"] == "hevc")
@@ -583,6 +592,56 @@ def calculate_online_checksum_file(file: Path, size: int) -> str:
     return checksum_algorithm(chunk + str(size).encode()).hexdigest()
 
 
+class DataLogger(Thread):
+    """
+    What to log:
+
+    System:
+      × Hardware info
+      ? Software info
+      × isisdl version
+
+
+    From ISIS:
+      × Username
+        How many courses
+        How
+
+
+    """
+
+    def __init__(self) -> None:
+        self.s = Session()
+        self.generic_msg = {
+            "username": User.sanitize_name(config.username),
+            "OS": platform.system(),
+            "OS_spec": distro.id(),
+            "version": __version__,
+            "is_first_time": is_first_time,
+            "message": "",
+        }
+
+        super().__init__(daemon=True)
+
+    def message(self, msg: str) -> None:
+        if is_testing:
+            return
+
+        self.generic_msg["message"] = msg
+
+        self.s.post("http://static.246.42.12.49.clients.your-server.de/isisdl/", json=self.generic_msg)
+
+    def post(self, msg: Dict[str, Any]) -> None:
+        if is_testing:
+            return
+
+        to_send = self.generic_msg.copy()
+        del to_send["message"]
+        to_send.update(msg)
+
+        self.s.post("http://static.246.42.12.49.clients.your-server.de/isisdl/", json=to_send)
+
+
 # Copied and adapted from https://stackoverflow.com/a/63839503
 class HumanBytes:
     @staticmethod
@@ -683,6 +742,10 @@ if is_first_time:
 colorama.init()
 startup()
 OnKill()
-database_helper = DatabaseHelper()
+
 args = get_args()
+database_helper = DatabaseHelper()
 config = Config()
+
+logger = DataLogger()
+logger.start()
